@@ -2,7 +2,7 @@
   filterthebat.cpp  -  TheBat! mail import
 
   SPDX-FileCopyrightText: 2005 Danny Kukawka <danny.kukawka@web.de>
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2024 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -39,10 +39,7 @@ FilterTheBat::FilterTheBat()
 }
 
 /** Destructor. */
-FilterTheBat::~FilterTheBat()
-{
-    delete d;
-}
+FilterTheBat::~FilterTheBat() = default;
 
 /** Recursive import of The Bat! maildir. */
 void FilterTheBat::import()
@@ -146,7 +143,7 @@ void FilterTheBat::importFiles(const QString &FileName)
     // First comes a header of 3K (3128 byte/ 0x00000c38), which we can forget.
     // The byte 3129 is the first character of the first message.
     //
-    // The end of a message is marked trough "! p 0" and 43 following characters.
+    // The end of a message is marked through "! p 0" and 43 following characters.
     // (within: "_UB", blanks and some other chars.) Together are 48 characters as
     // separator.
     // ----------------------------------------
