@@ -1,12 +1,12 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2024 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filterlnotestest.h"
-#include "filters/filterlnotes.h"
 #include "filterimportertest.h"
+#include "filters/filterlnotes.h"
 #include <QTest>
 
 FilterLnotesTest::FilterLnotesTest(QObject *parent)
@@ -26,12 +26,12 @@ void FilterLnotesTest::canNotImportDataEmptyPath()
 {
     MailImporter::FilterLNotes filter;
     MailImporter::FilterInfo info;
-    auto *importerTest = new FilterImporterTest(&info);
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
-    //TODO implement it
-    //filter.importMail(QString());
-    //QVERIFY(importerTest->filterImporterDataList().isEmpty());
+    // TODO implement it
+    // filter.importMail(QString());
+    // QVERIFY(importerTest->filterImporterDataList().isEmpty());
     delete importerTest;
 }
 
@@ -39,12 +39,14 @@ void FilterLnotesTest::canNotImportDataUnknowPath()
 {
     MailImporter::FilterLNotes filter;
     MailImporter::FilterInfo info;
-    auto *importerTest = new FilterImporterTest(&info);
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
-    //filter.importMails(QStringLiteral("/foo/kde/bla/toto/"));
-    //QVERIFY(importerTest->filterImporterDataList().isEmpty());
+    // filter.importMails(QStringLiteral("/foo/kde/bla/toto/"));
+    // QVERIFY(importerTest->filterImporterDataList().isEmpty());
     delete importerTest;
 }
 
 QTEST_MAIN(FilterLnotesTest)
+
+#include "moc_filterlnotestest.cpp"
